@@ -12,6 +12,7 @@ class Context(object):
         self._pos = pos
         self._script = None
         self._mode = None
+        self._acd_url = None
         self._parse()
 
     def _parse(self):
@@ -22,6 +23,8 @@ class Context(object):
         self._meter = self.Meter(tl.get('meter'))
         self._bench = self.Bench(tl.get('bench'))
         self._runtime = self.Runtime()
+        self._session = self.Session(self)
+        self._acd_url = tl.get('acd_url')
 
     #     self._bench = self.Bench(tl.get('bench'))
     #     self._case = self.Case(tl.get('cases').get(self.case_id))
@@ -67,6 +70,14 @@ class Context(object):
     def runtime(self):
         return self._runtime
 
+    @property
+    def session(self):
+        return self._session
+
+    @property
+    def acd_url(self):
+        return self._acd_url
+
     class Tester(object):
         def __init__(self, data: dict):
             self._ip = data.get('ip')
@@ -277,12 +288,12 @@ class Context(object):
 
         def __init__(self):
             self._step = -1
-            self._last_step_result = None
+            self._loop_sn = 0
             self._loop_start_step = 0
             self._loop_end_step = 0
             self._loop_count = 0
             self._loop_index = 0
-            self._loop_sn = 0
+            self._steps = {}
 
         @property
         def step(self):
@@ -293,12 +304,12 @@ class Context(object):
             self._step = value
 
         @property
-        def last_step_result(self):
-            return self._last_step_result
+        def loop_sn(self):
+            return self._loop_sn
 
-        @last_step_result.setter
-        def last_step_result(self, value):
-            self._last_step_result = value
+        @loop_sn.setter
+        def loop_sn(self, value):
+            self._loop_sn = value
 
         @property
         def loop_start_step(self):
@@ -333,11 +344,24 @@ class Context(object):
             self._loop_index = value
 
         @property
-        def loop_sn(self):
-            return self._loop_sn
+        def steps(self):
+            return self._steps
 
-        @loop_sn.setter
-        def loop_sn(self, value):
-            self._loop_sn = value
+
+    class Session(object):
+        def __init__(self, parent):
+            self._basename = '{}:{}:{}'.format(parent.test_sn
+                                                 , parent.case.id, parent.meter.pos)
+
+        def get(self, name: str, key: str):
+            return mm.Dict.get('{}:{}'.format(self._basename, name), key)
+
+        def set(self, name: str, key: str, data):
+            return mm.Dict.put('{}:{}'.format(self._basename, name), key, data)
+
+        @property
+        def basename(self):
+            return self._basename
+
 
 
