@@ -96,15 +96,24 @@ class METER(Operation):
         opt = op.get('operation')
         elem = op.get('element')
         param = op.get('parameter')
+        addi = op.get('addition')
+        se = op.get('security')
         acd = op.get('acd')
 
         code = "command.meter('{}').comm_addr('{}').operation('{}')" \
-            .format(clazz, self._context.meter.addr, opt.replace('_', ':'))
+            .format(clazz, self._context.meter.addr, opt)
 
         if elem is not None:
-            code += ".element('{}')".format(elem)
+            if type(elem) is str:
+                code += ".element('{}')".format(elem)
+            else:
+                code += ".element({})".format(elem)
         if param is not None:
             code += ".parameter({})".format(param)
+        if addi is not None:
+            code += ".addition({})".format(addi)
+        if se is not None:
+            code += ".security({})".format(se)
         if acd is not None:
             code += ".function({})".format(acd)
 
@@ -113,6 +122,17 @@ class METER(Operation):
         return code
 
 
+class EM(Operation):
+    def translate(self, op: dict):
+        clazz = op.get('clazz')
+        opt = op.get('operation')
+        param = op.get('parameter')
+
+        code = "command.encrypt('{}').operation('{}').parameter({}).exec(context)".format(clazz, opt, param)
+
+        return code
+
+
 class BENCH(Operation):
     def translate(self, op: dict):
         clazz = op.get('clazz')
@@ -121,7 +141,6 @@ class BENCH(Operation):
         function = op.get('function')
         sleep = op.get('sleep')
         interval = op.get('interval')
-        cache = op.get('cache')
 
         code = "command.bench('{}').operation('{}')".format(clazz, opt)
 
@@ -133,8 +152,6 @@ class BENCH(Operation):
             code += ".sleep({})".format(sleep)
         if interval is not None:
             code += ".interval({})".format(interval)
-        if cache is not None:
-            cache += ".cache({})".format(cache)
 
         code += ".exec(context)"
 
